==> GotoBLAS-1.17.tar.gz: GotoBLAS/lapack/potrf/potrf_L_parallel.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include <stdio.h>
#include "common.h"

static FLOAT dm1 = -1.;

blasint CNAME(long  n, FLOAT *a, long lda, FLOAT *buffer){

  long info;
  long bm, bk, i, blocking;
  int mode;

#ifndef COMPLEX
#ifdef XDOUBLE
  mode  =  BLAS_XDOUBLE | BLAS_REAL;
#elif defined(DOUBLE)
  mode  =  BLAS_DOUBLE  | BLAS_REAL;
#else
  mode  =  BLAS_SINGLE  | BLAS_REAL;
#endif  
#else
#ifdef XDOUBLE
  mode  =  BLAS_XDOUBLE | BLAS_COMPLEX;
#elif defined(DOUBLE)
  mode  =  BLAS_DOUBLE  | BLAS_COMPLEX;
#else
  mode  =  BLAS_SINGLE  | BLAS_COMPLEX;
#endif  
#endif

  if (n <= DTB_ENTRIES) {
    info = POTF2_L(n, a, lda, buffer);
    return info;
  }

  blocking = GEMM_Q;
  if (n <= 4 * GEMM_Q) blocking = n / 4;

  for (i = 0; i < n; i += blocking) {
    
    bk = MIN(blocking, n - i);

    info = CNAME(bk, a, lda, buffer);
    if (info) return info + i;
    
    bm = n - i - bk;

    if (bm > 0) {

      trsm_thread(mode | BLAS_RSIDE | BLAS_TRANSA_T | BLAS_UPLO, 
		  bm, bk, ZERO, ZERO,
		  a, lda,  a + bk * COMPSIZE, lda, 
		  (void *)TRSM_RCLN,
		  buffer);
      
      syrk_thread(mode | BLAS_TRANSA_N | BLAS_TRANSB_T | BLAS_UPLO,
		  bm, bk, dm1, ZERO,
		  a + (     bk      ) * COMPSIZE, lda,
		  NULL, 0,
		  a + (bk + bk * lda) * COMPSIZE, lda,
		  (void *)HERK_LN, buffer);
    }

    a += (1 + lda) * blocking * COMPSIZE;
  }
  
  return 0;
}

==> GotoBLAS-1.19.tar.gz: GotoBLAS/lapack/potrf/potrf_L_parallel.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include <stdio.h>
#include "common.h"

static FLOAT dm1 = -1.;

blasint CNAME(long  n, FLOAT *a, long lda, FLOAT *buffer){

  long info;
  long bm, bk, i, blocking;
  int mode;

#ifndef COMPLEX
#ifdef XDOUBLE
  mode  =  BLAS_XDOUBLE | BLAS_REAL;
#elif defined(DOUBLE)
  mode  =  BLAS_DOUBLE  | BLAS_REAL;
#else
  mode  =  BLAS_SINGLE  | BLAS_REAL;
#endif  
#else
#ifdef XDOUBLE
  mode  =  BLAS_XDOUBLE | BLAS_COMPLEX;
#elif defined(DOUBLE)
  mode  =  BLAS_DOUBLE  | BLAS_COMPLEX;
#else
  mode  =  BLAS_SINGLE  | BLAS_COMPLEX;
#endif  
#endif

  if (n <= DTB_ENTRIES / 2) {
    info = POTF2_L(n, a, lda, buffer);
    return info;
  }

  blocking = GEMM_Q;
  if (n <= 4 * GEMM_Q) blocking = n / 4;

  for (i = 0; i < n; i += blocking) {
    
    bk = MIN(blocking, n - i);

    info = CNAME(bk, a, lda, buffer);
    if (info) return info + i;
    
    bm = n - i - bk;

    if (bm > 0) {

      trsm_thread(mode | BLAS_RSIDE | BLAS_TRANSA_T | BLAS_UPLO, 
		  bm, bk, ZERO, ZERO,
		  a, lda,  a + bk * COMPSIZE, lda, 
		  (void *)TRSM_RCLN,
		  buffer);
      
      syrk_thread(mode | BLAS_TRANSA_N | BLAS_TRANSB_T | BLAS_UPLO,
		  bm, bk, dm1, ZERO,
		  a + (     bk      ) * COMPSIZE, lda,
		  NULL, 0,
		  a + (bk + bk * lda) * COMPSIZE, lda,
		  (void *)HERK_LN, buffer);
    }

    a += (1 + lda) * blocking * COMPSIZE;
  }
  
  return 0;
}
